/********************************************************************************************************\

	File Name:	CommonVictoryBaseState.cpp
	Descript:	<DESCRIPTION>

\********************************************************************************************************/

#include "Team1.h"
#include "Team2.h"
#include "Team3.h"
#include "Team4.h"
#include "Team5.h"
#include "Team6.h"
#include "TeamA.h"
#include "TeamB.h"
#include "CommonVictoryBaseState.h"
#include "MissionText.h"
#include "ScriptInterface.h"
#include "ShipScriptDescription.h"
#include "WorldConditions.h"
#include "EventMgr.h"

//
//	Serialization events
//
tCommonVictoryBaseState::tCommonVictoryBaseState( int32 astoundingVictory, int32 victory, int32 draw, int32 defeat, int32 devastatingDefeat ) :
	tChildActorVictoryState<tCommonVictory>( astoundingVictory, victory, draw, defeat, devastatingDefeat )
{}
void tCommonVictoryBaseState::mBeginState()
{}
void tCommonVictoryBaseState::mEndState()
{}
/*

	HELPER NOTE:	The following function will calculate how the team did once you end the mission with
					a call to mSetGameStatus() for this specific team.  It is not necessary to have every
					victory condition handled here (e.g. kAstoundingVictory...kDevastatingDefeat),
					especially if the victory condition is simply a boolean value (e.g. killed or
					has killed).  Also notice that the example is using the world condition for analysis.
					An example follows.

	eVictoryLevels
	tCommonVictoryBaseState::mCalcVictoryStatus()
	{
		if ( gWC.mField1() )
		{
			//
			//	objective was completed.
			//
			return kAstoundingVictory;
		}
		else
		{
			//
			//	objective was not completed.
			//
			return kDevastatingDefeat;
		}
	}

*/
eVictoryLevels tCommonVictoryBaseState::mCalcVictoryStatus( eTeamID ID )
{
	if ((fChildActor->mGetTeam()->mGetTag() == kTagA && gWC.mDidHomeWin()) ||
		(fChildActor->mGetTeam()->mGetTag() == kTagB && !gWC.mDidHomeWin()))
	{
		return kAstoundingVictory;
	}
	else
	{
		return kDevastatingDefeat;
	}
}

//
//	Ship events
//
/*

	HELPER NOTE:	Inside each of the following functions, the ship parameter can be examined to determine
					which ship received the corresponding event.  You can find out which ship it is by
					determining its custom ID.  Remember, since this is a victory condition, there is no
					reason to check the ship against 'fChildActor'.  Simply examine the team and ship as
					described below and end the game appropriately, if needed with a call to mSetGameStatus().

					Please REMEMBER TO TAKE CARE OF onCapture, onDeath, and onDisengage events for the player
					ship since not doing so will freeze the game.  In other words, you MUST tell the game that
					it is OVER!  It has been started for you; however, if the player has multiple ships under
					control, you must run the player's ship list for any other ships that could be in play.

	void
	tBaseVictoryState::mOnEvent1( tShipInfo* ship )
	{
		switch ( ship->mGetTeam() )
		{
		case kMadeUpTeam:
			{
				switch ( ship->mGetCustomID() )
				{
				case kMadeUpID:
					{
						//
						//	the ship with custom ID of 'kMadeUpID' has been fField1-ed and in this case, the
						//	player should lose for whatever reason.  Remember, the call to mSetGameStatus()
						//	will call mCalcVictoryStatus() as described above.
						//
						fChildActor->mSetField1( true );
						gScriptInterface.mSetGameStatus( kPlayerLoses );
					}
					break;
				}
			}
			break;

		case etc...
		}

		if ( ship->mGetTeam() == kPlayerTeam )
		{
			//
			//	the player fField1-ed, so the player has accomplished the primary objective.
			//
			tTeamInfo* team = fMissionInfo->mGetTeamHandle( static_cast< eTeamID >( kPlayerTeam ) );
			if ( team )
			{
				if ( !team->mShipsCurrentlyControlled() )
				{
					gScriptInterface.mSetGameStatus( kPlayerLoses );
				}
			}
		}
	}

*/
void tCommonVictoryBaseState::mOnDeath( tShipInfo* ship )
{if ( !ship )
		return;
for (int team = (int)kTeam1; team <= (int)kTeam8; team++)
		{
tTeamInfo* ti = fMissionInfo->mGetTeamHandle( static_cast< eTeamID >( team ) );
Assert( ti );
	if ( !ti )
		return;

        if ( fChildActor->mGetTeam()->mGetTag() == kTagA && ti->mGetShipsInPlayCount() >0 )
		{
			
		mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
		}
        if ( fChildActor->mGetTeam()->mGetTag() == kTagB && ti->mGetShipsInPlayCount() >0 )
		{
		
		mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
		}
	    if ( fChildActor->mGetTeam()->mGetTag() == kTagA && ti->mGetShipsInPlayCount() <=0 )
		{
        // "mSetGameStatus" will conflict with World Conditions. Simply allow World Conditions to determine the final out come.  
		//gScriptInterface.mSetGameStatus( static_cast< eTeamID >( team ), kPlayerDestroyed );
		mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
		}

		if (fChildActor->mGetTeam()->mGetTag() == kTagB && ti->mGetShipsInPlayCount() <=0 )
		{
       
		//gScriptInterface.mSetGameStatus( static_cast< eTeamID >( team ), kPlayerDestroyed );
		mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
		}

}

}

void tCommonVictoryBaseState::mOnCapture( tShipInfo* ship )
{

	
	 	
  		
		for (int team = (int)kTeam1; team <= (int)kTeam8; team++)
		{
			tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)team);
		
			if (tci->mGetTag() == kTagB)
			{
				ship->mSetTeam(kTeam9); 
				mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
								
			}
			
			if (tci->mGetTag() == kTagA )
			{
			  	ship->mSetTeam(kTeam9);
				mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
								
			}
		}
	


}

void tCommonVictoryBaseState::mOnDisengaged( tShipInfo* ship )
{

mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);


/*	
		for (int team = (int)kTeam1; team <= (int)kTeam8; team++)
		{
			tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)team);
		
			if (tci->mGetTag() == kTagB)
			{				 
				mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
								
			}
			
			if (tci->mGetTag() == kTagA )
			{		  	
			  mSetTimedInterval(kTimerSecondsSet, 5, 5.0f);
								
			}
		}
*/		
}

  
void tCommonVictoryBaseState::mAtDistance( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mAtDestination( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mOnCommButtonPress( tShipInfo* ship, int32 buttonID, tShipInfo* targetShip )
{}
void tCommonVictoryBaseState::mOnDamage( tShipInfo* damagedShip, tShipInfo* hostileShip, eDamageToShip damageType )
{}
void tCommonVictoryBaseState::mOnDeepScan( tShipInfo* ship, iTruth deepScanOn )
{}
void tCommonVictoryBaseState::mOnAlertStatusChange( tShipInfo* ship, eAlertLevels alertStatus )
{}
void tCommonVictoryBaseState::mOnProbeLaunch( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mOnBeginOrbit( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mOnEndOrbit( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mOnBeginTractor( tShipInfo* tractorTarget, tShipInfo* tractoringShip )
{}
void tCommonVictoryBaseState::mOnEndTractor( tShipInfo* tractorTarget, tShipInfo* tractoringShip )
{}
void tCommonVictoryBaseState::mOnFlashingButtonPressed()
{}
void tCommonVictoryBaseState::mOnTransportedItem( tShipInfo* shipTo, tShipInfo* shipFrom, eScriptTransportItems item )
{}
void tCommonVictoryBaseState::mOnChangingShip( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mOnSpecialTransport( tShipInfo* ship )
{}
void tCommonVictoryBaseState::mOnShipSystemUpdate( tShipInfo* ship, eShipUpdateType type, eSystemHardPoint system, int32 value )
{}
void tCommonVictoryBaseState::mOnShipSystemUpdate( tShipInfo* ship, eShipUpdateType type, eSystemHardPoint system, float percent )
{}
void tCommonVictoryBaseState::mOnShipStoresUpdate(	tShipInfo* ship, eShipUpdateType type,
													eAccessShipStores_ItemTypes item, eAccessShipStores_SubTypes subItem, int32 value )
{}
void tCommonVictoryBaseState::mOnShipStoresUpdate(	tShipInfo* ship, eShipUpdateType type,
													eAccessShipStores_ItemTypes item, eScriptTransportItems subItem, int32 value )
{}

//
//	System events
//

/*

	HELPER NOTE:	When this event is called, you need to pretend that the team associated with the
					playerNumber has been defeated.  So call what you need to, so that you may determine
					if the game has ended.  For instance, a world condition?

*/
void tCommonVictoryBaseState::mOnPlayerLeaving( int playerNumber )
{}
void tCommonVictoryBaseState::mOnHostChanged()
{}
void tCommonVictoryBaseState::mOnTimedInterval( int32 timerID )
{
	{
		if (timerID == 4)
		{   //force game to end and file dump if a final ship from a team disengages.
		    gWC.mCheckForGameEnd();
			gWC.mSetGameEnded(kTrue);
		}
		if (timerID == 5)
		{

gWC.mCheckForGameEnd();
		}
	}

}
void tCommonVictoryBaseState::mOnStateChange( tActor* actor, tState* stateID, eStateEvent eventType )
{}
void tCommonVictoryBaseState::mOnCommStateChange( tActor* actor, int32 state, int32 buttonID, eStateEvent eventType )
{}


