/********************************************************************************************************\

	File Name:	MissionMaps.cpp
	Descript:	<DESCRIPTION>

\********************************************************************************************************/

#include "tclient.h"
#include "MissionMaps.h"

/*
	G-L are fixed starting positions for the 6 teams
*/
int32 TotalMaps = 6;
const char* MapTypes[] = {	"Open Space",
							"Planets",
							"Asteroid Field",
							"Asteroid Belt",
							"Nebula",
							"Black Hole" };

/*
	Legend:
			Starting Positions			Ending Positions			Planets			
			Start1 --> G				End1 --> g					Earth --> 1
			Start2 --> H				End2 --> h					Ringed Earth --> 2
			Start3 --> I				End3 --> i					Mars --> 3
			Start4 --> J				End4 --> j					Jupiter --> 4
			Start5 --> K				End5 --> k					Organia --> 5
			Start6 --> L				End6 --> l					Saturn --> 6
			Start7 --> M				End7 --> m					Night City --> 7
			Start8 --> N				End8 --> n					Fire --> 8
			Start9 --> O				End9 --> o					Ice --> 9
			Start10 --> P				End10 --> p					Gas --> 0
			Start11 --> Q				End11 --> q					
			Start12 --> R				End12 --> r					
			Start13 --> S				End13 --> s					
			Start14 --> T				End14 --> t					
			Start15 --> U				End15 --> u					
			Start16 --> V				End16 --> v					
			Start17 --> W				End17 --> w					
			Start18 --> X				End18 --> x					
			Start19 --> Y				End19 --> y					
			Start20 --> Z				End20 --> z					

			Celestial Bodies			Asteroids					Black Holes
			Moon --> @					SmallAsteroid --> [			SmallBlackHole --> :
			Sun1 --> (					LargeAsteroid --> ]			LargeBlackHole --> ,
			Sun2 --> )					IceAsteroid --> *			
			Sun3 --> !
			
			Nebulas						Dust Clouds					Other
			Nebula1 --> &				LightDustCloud --> <		WormHole --> %
			Nebula2 --> ?				HeavyDustCloud --> >		Fissure --> $
																	Corpse --> #
																	Organian --> ^
																	Pulsar --> ~
*/
const char* MapLines[]=
{
   "Mul_FleetPickOP",
   "// Open Space",
   " +____1____2____3____4____5____6____7____8+",
   " |........................................|",
   "1|........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "2|..............X....Y....Z...............|",
   " |..............x....y....z...............|",
   " |...................W....................|",
   " |...................w....................|",
   " |.........R....S....T....U....V..........|",
   "3|.........r....s....t....u....v..........|",
   " |...................Q....................|",
   " |...................q....................|",
   " |........................................|",
   " |........................................|",
   "4|........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "5|........................................|",
   " |........................................|",
   " |........................................|",
   " |...................g....................|",
   " |...................G....................|",
   "6|.........h....i....j....k....l..........|",
   " |.........H....I....J....K....L..........|",
   " |...................m....................|",
   " |...................M....................|",
   " |..............n....o....p...............|",
   "7|..............N....O....P...............|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "8|........................................|",
   " +----------------------------------------+",
   "      1    2    3    4    5    6    7    8",
   "// Planets",
   " +____1____2____3____4____5____6____7____8+",
   " |........................................|",
   "1|........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "2|..............X....Y....Z...............|",
   " |..............x....y....z...............|",
   " |...................W....................|",
   " |...................w....................|",
   " |.........R....S....T....U....V..........|",
   "3|.........r....s....t....u....v..........|",
   " |...................Q....................|",
   " |...................q....................|",
   " |....7...................................|",
   " |........................................|",
   "4|........................................|",
   " |........................................|",
   " |...................6....................|",
   " |........................................|",
   " |........................................|",
   "5|........................................|",
   " |..................................3.....|",
   " |........................................|",
   " |...................g....................|",
   " |...................G....................|",
   "6|.........h....i....j....k....l..........|",
   " |.........H....I....J....K....L..........|",
   " |...................m....................|",
   " |...................M....................|",
   " |..............n....o....p...............|",
   "7|..............N....O....P...............|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "8|........................................|",
   " +----------------------------------------+",
   "      1    2    3    4    5    6    7    8",
   "// Asteroid Field",
   " +____1____2____3____4____5____6____7____8+",
   " |........................................|",
   "1|.....*............................*.....|",
   " |....***..........................***....|",
   " |.....*............................*.....|",
   " |........................................|",
   "2|..............X....Y....Z...............|",
   " |..............x....y....z...............|",
   " |...................W....................|",
   " |...[.].............w..............[.]...|",
   " |.........R....S....T....U....V..........|",
   "3|.........r....s....t....u....v..........|",
   " |...................Q....................|",
   " |...................q....................|",
   " |........................................|",
   " |....[][]........................[][]....|",
   "4|...[][][]......................[][][]...|",
   " |....[][]..........[]............[][]....|",
   " |................[][][]..................|",
   " |..................[]....................|",
   " |........................................|",
   "5|....[..]........................[..]....|",
   " |........................................|",
   " |........................................|",
   " |...................g....................|",
   " |...................G....................|",
   "6|.........h....i....j....k....l..........|",
   " |.........H....I....J....K....L..........|",
   " |...................m....................|",
   " |...................M....................|",
   " |..............n....o....p...............|",
   "7|..............N....O....P...............|",
   " |....*..............................*....|",
   " |...***............................***...|",
   " |....*..............................*....|",
   " |........................................|",
   "8|........................................|",
   " +----------------------------------------+",
   "      1    2    3    4    5    6    7    8",
   "// Asteroid Belt",
   " +____1____2____3____4____5____6____7____8+",
   " |........................................|",
   "1|........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "2|..............X....Y....Z...............|",
   " |..............x....y....z...............|",
   " |...................W....................|",
   " |...................w....................|",
   " |.........R....S....T....U....V..........|",
   "3|.........r....s....t....u....v..........|",
   " |...................Q....................|",
   " |...................q....................|",
   " |........................................|",
   " |........................................|",
   "4|.*.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.*..|",
   " |.[....................................[.|",
   " |..[.<><><><><><><><>>><>>>><><><><><.[..|",
   " |...[................................[...|",
   " |....[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.....|",
   "5|........................................|",
   " |........................................|",
   " |........................................|",
   " |...................g....................|",
   " |...................G....................|",
   "6|.........h....i....j....k....l..........|",
   " |.........H....I....J....K....L..........|",
   " |...................m....................|",
   " |...................M....................|",
   " |..............n....o....p...............|",
   "7|..............N....O....P...............|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "8|........................................|",
   " +----------------------------------------+",
   "      1    2    3    4    5    6    7    8",
   "// Nebula",
   " +____1____2____3____4____5____6____7____8+",
   " |........................................|",
   "1|..&.....................................|",
   " |........................................|",
   " |...............................{........|",
   " |........................................|",
   "2|...{..........X....Y....Z...............|",
   " |..............x....y....z...............|",
   " |...................W....................|",
   " |...................w....................|",
   " |.........R....S....T....U....V..........|",
   "3|.........r....s....t....u....v.....{....|",
   " |...................Q....................|",
   " |...................q....................|",
   " |........................................|",
   " |......{.................................|",
   "4|........................................|",
   " |........................................|",
   " |...........................{............|",
   " |................{.......................|",
   " |........................................|",
   "5|........................................|",
   " |........................................|",
   " |....{............................{......|",
   " |...................g....................|",
   " |...................G....................|",
   "6|.........h....i....j....k....l..........|",
   " |.........H....I....J....K....L..........|",
   " |...................m....................|",
   " |...................M....................|",
   " |..............n....o....p...............|",
   "7|..............N....O....P...............|",
   " |..............................{.........|",
   " |........................................|",
   " |....{...................................|",
   " |........................................|",
   "8|........................................|",
   " +----------------------------------------+",
   "      1    2    3    4    5    6    7    8",
   "// Black Hole",
   " +____1____2____3____4____5____6____7____8+",
   " |........................................|",
   "1|........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "2|..............X....Y....Z...............|",
   " |..............x....y....z...............|",
   " |...................W....................|",
   " |...................w....................|",
   " |.........R....S....T....U....V..........|",
   "3|.........r....s....t....u....v..........|",
   " |...................Q....................|",
   " |...................q....................|",
   " |........................................|",
   " |........................................|",
   "4|........................................|",
   " |........................................|",
   " |...................B....................|",
   " |........................................|",
   " |........................................|",
   "5|........................................|",
   " |........................................|",
   " |........................................|",
   " |...................g....................|",
   " |...................G....................|",
   "6|.........h....i....j....k....l..........|",
   " |.........H....I....J....K....L..........|",
   " |...................m....................|",
   " |...................M....................|",
   " |..............n....o....p...............|",
   "7|..............N....O....P...............|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   " |........................................|",
   "8|........................................|",
   " +----------------------------------------+",
   "      1    2    3    4    5    6    7    8",
   "///",
   0
};
