/*
 * Find.cpp
 *
 * (C) 2001 MagnumMan-iCoP (James E. King, III)
 */

#include "StdAfx.h"

#include "ShipList.h"

bool ShipList::Find(const char *shipCode, Ship &aShip)
{
	return Find(std::string(shipCode), aShip);
}

bool ShipList::Find(std::string shipCode, Ship &aShip)
{
	SHIP_LIST_ITER(*this)
		
		if (!iter->shipCode.compare(shipCode))
		{
			aShip = *iter;
			return true;
		}

	SHIP_LIST_ITER_END

	return false;
}

bool ShipList::FindFighter(const char *shipCode, Ship &aShip)
{
	return FindFighter(std::string(shipCode), aShip);
}

bool ShipList::FindFighter(std::string shipCode, Ship &aShip)
{
	SHIP_LIST_ITER(fighters_and_pfs)
		
		if (!iter->shipCode.compare(shipCode))
		{
			aShip = *iter;
			return true;
		}

	SHIP_LIST_ITER_END

#ifdef _DEBUG
	DebugBreak();		// help detect missing fighters
#endif

	return false;
}

bool ShipList::Remove(const char *shipCode)
{
	return Remove(std::string(shipCode));
}

bool ShipList::Remove(std::string shipCode)
{
	SHIP_LIST_ITER(*this)
		
		if (!iter->shipCode.compare(shipCode))
		{
			erase(iter);
			return true;	// Assume ships unique by name, which they are
		}

	SHIP_LIST_ITER_END

	return false;
}

int32 ShipList::MinimumBPV(void)
{
	int32	minv = 99999;

	SHIP_LIST_ITER(*this)

		if (iter->bpv < minv)
			minv = iter->bpv;

	SHIP_LIST_ITER_END

	return minv;
}

int32 ShipList::MaximumBPV(void)
{
	int32	maxv = -1;

	SHIP_LIST_ITER(*this)

		if (iter->bpv > maxv)
			maxv = iter->bpv;

	SHIP_LIST_ITER_END

	return maxv;
}

int32 ShipList::TotalBPV(void)
{
	int32	tot = 0;

	SHIP_LIST_ITER(*this)

		tot += iter->bpv;

	SHIP_LIST_ITER_END

	return tot;
}

// private

bool	ShipList::FindSpecsDirectory(eGame game, bool meta, std::string &location)
{
	HKEY	hKey;
	LONG	lval;
	DWORD	type;
	char	path[256];
	DWORD	siz = 256;

	if (game == kOrionPirates)
	{
		lval = RegOpenKeyEx(HKEY_LOCAL_MACHINE,
							"Software\\Taldren\\Starfleet Command Orion Pirates",
							0,
							KEY_QUERY_VALUE,
							&hKey);

		if (lval != ERROR_SUCCESS)
			return false;

		lval = RegQueryValueEx(	hKey,
								"Directory",
								0,
								&type,
								(unsigned char *)path,
								&siz );

		RegCloseKey(hKey);

		if (lval != ERROR_SUCCESS)
			return false;
	}
	else if (game == kEmpiresAtWar)
	{
		lval = RegOpenKeyEx(HKEY_LOCAL_MACHINE,
							"Software\\Taldren\\Starfleet Command II",
							0,
							KEY_QUERY_VALUE,
							&hKey);

		if (lval != ERROR_SUCCESS)
			return false;

		lval = RegQueryValueEx(	hKey,
								"Path",
								0,
								&type,
								(unsigned char *)path,
								&siz );

		RegCloseKey(hKey);

		if (lval != ERROR_SUCCESS)
			return false;
	}
	else
	{
		DebugBreak();
	}

	path[siz] = 0;
	if (path[siz - 1] != '\\')
		strcat(path, "\\");

	if (meta)
		strcat(path, "MetaAssets\\");
	else
		strcat(path, "Assets\\specs\\");

	location = path;
	return true;
}
