/********************************************************************************************************\

	File Name:	Team5.cpp
	Descript:	<DESCRIPTION>

\********************************************************************************************************/

#include "tclient.h"
#include "MissionText.h"
#include "ShipScriptDescription.h"
#include "Team5.h"
#include "CommonTeamState.h"
#include "FleetPickData.h"
#include "ShipList.h"
#include "DummyState.h"
#include "CommonVictory.h"
#include "CommonVictoryBaseState.h"
#include "VictoryCondition.h"
#include "WorldConditions.h"


tClassAllocator<tTeam5> gTeam5Allocator;

static bool FindScriptsDirectory(std::string &location)
{
   HKEY	hKey;
	LONG	lval;
	DWORD	type;
	char	path[256];
	DWORD	siz = 256;

	lval = RegOpenKeyEx(HKEY_LOCAL_MACHINE,
						"Software\\Taldren\\Starfleet Command Orion Pirates",
						0,
						KEY_QUERY_VALUE,
						&hKey);

	if (lval != ERROR_SUCCESS)
		return kFalse;

	lval = RegQueryValueEx(	hKey,
							"Directory",
							0,
							&type,
							(unsigned char *)path,
							&siz );

	RegCloseKey(hKey);

	if (lval != ERROR_SUCCESS)
		return kFalse;

	path[siz] = 0;
	if (path[siz - 1] != '\\')
		strcat(path, "\\");

	strcat(path, "Assets\\Scripts\\");

	location = path;
	return kTrue;

}

/*

	HELPER NOTE:	The victory condition for this team is specific to this team and only to this team.

*/
void tTeam5::mSetupVictoryCondition()
{
	fVictoryCondition = new tCommonVictory( this );
    gEventMgr.mRegisterActor( fVictoryCondition );
}

void tTeam5::mSetupDebriefingList( eVictoryLevels victoryLevel )
{
	switch ( victoryLevel )
	{
	case kAstoundingVictory:
	case kVictory:
		fMissionInfo->mAddToDebriefingList( fTeam, kWinner_msg );		break;
	case kDevastatingDefeat:
	case kDefeat:
		fMissionInfo->mAddToDebriefingList( fTeam, kLoser_msg );		break;
	case kUnknownVictoryLevel:
		fMissionInfo->mAddToDebriefingList( fTeam, kLeftEarly_msg );	break;
	case kDraw:
	default:
		fMissionInfo->mAddToDebriefingList( fTeam, kDefault_msg );		break;
	}
}

/*

	HELPER NOTE:	If you create any new states on the team level, you must register them here first.

*/
void tTeam5::mSetupState()
{
	mRegisterState( new tCommonTeamState() );
	mGotoState( typeid( tCommonTeamState ) );
}

/*

	HELPER NOTE:	The comm states should include the team they apply for when registered.

*/
void tTeam5::mSetupCommState()
{}

/*

	HELPER NOTE:	In this function, you will create the ships for the team described by the file name.
					It is a good idea to give each of these ships a custom ID so that it can be referred
					to later (i.e. victory condition).  The custom IDs are listed in the matching header file.
					The ships can be created in one of two ways.  There are examples of both below.  One last
					thing, when you create these ships, you have to remember to include their class headers at
					the top of this file; otherwise, this file will not compile.

	//
	//	CREATE SHIP #1: Creates a ship based on the team's BPV.
	//
	mCreateShip(	typeid( tPlayerNPCBS1 ),
					nPCBPV,
					kClassHeavyBattlecruiser,
					0,
					kStartPosition_G,
					kPlayerNPCBS1 );

	//
	//	CREATE SHIP #2: Creates a ship based on one of the spec records found in the spec chart.
	//
	mCreateShip( typeid( tPlayerNPCBS1 ), "PL3" , kStartPosition_J, kPlayerNPCBS2 );

*/
void tTeam5::mCreateShipsForTeam()
{
const char *CustomName;
   
   if( gFPD.mIsShipSelected(kHostSelectShip))
   {	

	char buf[64];
	std::string gShip5; 
	std::string	scriptsINI;
	FindScriptsDirectory(scriptsINI);
	scriptsINI += "scripts.ini";
	
	DWORD	rv = GetPrivateProfileString("Mul_FleetPick", "shipP5",
		            "", buf, 64,
					scriptsINI.c_str());
	if (rv)
   gShip5 = buf;
	else
	NULL;

	rv = GetPrivateProfileString("Mul_FleetPick", "p5Pos",
		            "", buf, 64,
					scriptsINI.c_str());
	if (rv)
	gFPD.m_p5_pos = atof(buf);
	else
	gFPD.m_p5_pos = -1;


   	 		
ShipList sl;

Ship s;

sl.CreateMaster(ShipList::kOrionPirates, false);


    	if (mGetTag() == kTagA )
		{
		CustomName = "Player Team A";
		}	
		else
		{
		CustomName = "Player Team B";
		}
		       sl.Find(gShip5,(s));
		
		       mCreateShip( typeid( tShipInfo),		             
                s.shipCode.c_str(),
				gFPD.m_p5_pos,
		    	kNoMetaShipID,
				-1, 0, 0, -1, -1, CustomName, 
		 	    kDeathUponCapture);
   }

}


void tTeam5::mTeamSetupComplete()
{
	tTeamInfo::mTeamSetupComplete();
}


void tTeam5::mCreateNewShip( const tShipScriptDescription& shipScriptDescription )
{

	gFPD.Load();
	
	if( gFPD.mIsShipSelected(kPlyrSelectShip))
	{
	
	char buf[64];
    std::string	scriptsINI;
	FindScriptsDirectory(scriptsINI);
	scriptsINI += "scripts.ini";
	
	
	
	DWORD	rv = GetPrivateProfileString("Mul_FleetPick", "p5Pos",
		            "", buf, 64,
					scriptsINI.c_str());
	if (rv)
		gFPD.m_p5_pos = atof(buf);
	else
		gFPD.m_p5_pos = -1;


    
        	
	             mCreateShip( typeid( tShipInfo ),
				 shipScriptDescription.fClassName.c_str(), 
				 gFPD.m_p5_pos | shipScriptDescription.fTeamID,
				 kNoMetaShipID,
				 -1, 0, 0, -1, -1,
				 shipScriptDescription.fCustomName.c_str(),
				 static_cast< eShipOptions >( kDefaultShipOptions | kCanBeCarrier ) );
	}
}

