/********************************************************************************************************\

	File Name:	WorldConditions.cpp
	Descript:	<DESCRIPTION>

\********************************************************************************************************/
#include "tclient.h"
#include "ScriptInterface.h"
#include "WorldConditions.h"
#include "FleetPickData.h"
#include "tstring.h"
#include "StatsTeam.h"
#include "DummyState.h"
#include "MissionText.h"







/*

	HELPER NOTE:	This global reference to the world condition is here twofold.  One, it can be easily
					accessed from the all victory states; two, it maintains the consistancy relatively
					easily throughout the script.

*/
class tWorldConditions gWC;




/*

	HELPER NOTE:	Remember to instantiate your world conditions here.

*/
tWorldConditions::tWorldConditions()
{
	didFinality = kFalse;
	gameEnded = kFalse;
	homeWon = kFalse;
}


/*

	HELPER NOTE:	Acts as a sort of victory condition for all of the teams.  This is where you can
					analyze the game state according to the world conditions you have kept.  It is recommended
					that you call ::mSetGameStatus() here, when a victory decision has been made for all teams.

*/
void tWorldConditions::mCheckForGameEnd( void )
{
	int32 homeTeamShipCount = 0;
	int32 awayTeamShipCount = 0;
	int32 team;
	
	char buf[64];
    std::string	scriptsINI;
	std::string m_str_gameset;

    gFPD.FindScriptsDirectory(scriptsINI);
	scriptsINI += "scripts.ini";
	
	
	
	DWORD	rv = GetPrivateProfileString("Mul_FleetPick", "GameSet",
		            "", buf, 64,
					scriptsINI.c_str());
	if (rv)
		m_str_gameset = buf;
	else
		m_str_gameset = gFPD.m_str_gameset;
	
	
	        


	//
	// Check to see if there are any enemy ships left.
	// If none left, player wins.
	//

	for (team = (int)kTeam1; team <= (int)kTeam8; team++)
	{
		tTeamInfo *ti = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)team);
	
		if (ti)
		{
			tShipIterator	tsi = ti->mGetFirstShip();
			while (*tsi)
			{
				// If ship captured, it'll be on a different team

				tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)tsi->mGetTeam());
			   
				{
					    if (tci->mGetTag() == kTagA) 
					  	homeTeamShipCount++;
                        if (tci->mGetTag() == kTagB)
					   	awayTeamShipCount++;
				
					
					}
                
				tsi++;
			}
		}
	}


    if (awayTeamShipCount <= 0 )   
	{
	   	mSetGameEnded(kTrue);
		mSetHomeWon(kTrue);

  		// All away ships are gone

		for (int team = (int)kTeam1; team <= (int)kTeam8; team++)
		{
			tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)team);
			if (tci)
			{
				if (tci->mGetTag() == kTagA)
					gScriptInterface.mSetGameStatus((eTeamID) team, kPlayerWins);
				else
					gScriptInterface.mSetGameStatus((eTeamID) team, kPlayerLoses);
			}
		}
	}
	if (homeTeamShipCount <= 0 ) 
	{
		mSetGameEnded(kTrue);
		mSetHomeWon(kFalse);

	    
		// All home ships are gone

		for (int team = (int)kTeam1; team <= (int)kTeam8; team++)
		{
			tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)team);
			if (tci)
			{         
				if (tci->mGetTag() == kTagB)
					gScriptInterface.mSetGameStatus((eTeamID) team, kPlayerWins);
				else
					gScriptInterface.mSetGameStatus((eTeamID) team, kPlayerLoses);
			}
		}
	}
   if (mGetGameEnded() && didFinality == kFalse)
   {
	didFinality = kTrue;

    
				         	
   FILE *fp = fopen("C:\\FleetPick Records.TXT", "w" );
        fprintf(fp, "==================================================\n");
		fprintf(fp, "|                   Fleet Pick Records           |\n");
		fprintf(fp, "==================================================\n\n");
        
		if (gScriptInterface.mIsHost())
		{
		fprintf(fp, "GAME SET: '%s'\n", m_str_gameset.c_str());
		}
		if (!gScriptInterface.mIsHost())
		{
		fprintf(fp, "GAME SET: Host Custom Game Set\n");
		}
		if( gFPD.mIsShipSelected(kHostSelectShip) )
		{
           fprintf(fp, "SETTINGS: 'Host Selected Ships'\n");
		}
		if( gFPD.mIsShipSelected(kPlyrSelectShip) )
		{
           fprintf(fp, "SETTINGS: 'Player(s) Selected Ships'\n");
		}
				
		if( gFPD.mGetAIIntel() == 0)
		{
          fprintf(fp, "DIFFICULTY LEVEL: ( Captain )\n\n");
		}
		
		if( gFPD.mGetAIIntel() == 1)
		{
          fprintf(fp, "DIFFICULTY LEVEL: ( Commodore )\n\n");
		}
		
		if( gFPD.mGetAIIntel() == 2)
		{
          fprintf(fp, "DIFFICULTY LEVEL: ( Admiral )\n");
		}
		fprintf(fp, "==================================================\n\n");
	
	char buf[512];
	sprintf(buf, "Game results dumped to C:\\FleetPick Records.TXT");
	for (int j = (int)kTeam1; j <= (int)kTeam6; j++)
	{
gScriptInterface.mMission()->mDisplayMessage((eTeamID)j, " ");
gScriptInterface.mMission()->mDisplayMessage((eTeamID)j, buf);
	   
	}
		
	        
		for (int team = (int)kTeam1; team <= (int)kTeam8; team++)
		{
			tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle((eTeamID)team);
			if (tci)    
			{
				MissingShipList::iterator	msli;

                
				if (tci->mGetTag() == kTagA && team <= kTeam6)
					fprintf(fp, "Player Team %d (A Team Ship) \n", (team - kTeam1) + 1);
				
				if (tci->mGetTag() == kTagB && team <= kTeam6) 
					fprintf(fp, "Player Team %d (B Team Ship)\n", (team - kTeam1) + 1);

				if (tci->mGetTag() == kTagA && team >= kTeam7)
					fprintf(fp, "AI Team %d: (A Team Ship) \n", (team - kTeam1) + 1 );
				
				if (tci->mGetTag() == kTagB && team >= kTeam7) 
					fprintf(fp, "AI Team %d: (B Team Ship)\n", (team - kTeam1) + 1);
                 
				fprintf(fp, "    Ships Remaining:\n");
				tShipIterator tsi = tci->mGetFirstShip();
				while (*tsi)
				{
					fprintf(fp, "        Ship Name '%s'; Type %s; Endgame Health %2.1f%%\n",
						tsi->mGetCustomName(),
						tsi->mGetClassName(), 100.0f - tsi->mGetDamagePercent());
					if (tsi->mGetTeam() == static_cast<eTeamID>(kTeam9))
						fprintf(fp, "        <<>> SHIP DISENGAGED AND <<>>\n");
					if (tsi->mGetTeam() != static_cast<eTeamID>( team ) )
						fprintf(fp, "        <<>> CAPTURED BY TEAM %d <<>>\n", (tsi->mGetTeam() - kTeam1) + 1);
					
					tsi++;
				}

				fprintf(fp, "    Ships Disengaged:\n");
				for (msli = shipsDisengaged.begin(); msli != shipsDisengaged.end(); msli++)
				{
					if (msli->tid == team)
					{
						fprintf(fp, "        Ship Name '%s'; Type %s; Disengaged during game.\n",
						msli->name.c_str(), msli->code.c_str());
                    					
					}
				}

				fprintf(fp, "    Ships Destroyed:\n");
				for (msli = shipsDestroyed.begin(); msli != shipsDestroyed.end(); msli++)
				{
					if (msli->tid == team)
					{
						fprintf(fp, "        Ship Name '%s'; Type %s\n", msli->name.c_str(), msli->code.c_str());
					}
				}

               
				fprintf(fp, "\n");
			}
		}

		fclose(fp);
	 	}
	
   
	}  



void tWorldConditions::mSetShipDestroyed(eTeamID tid, std::string code, std::string name)
{ 
	char buf[255];
	tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle(tid);
	if (tci->mGetTag() == kTagA )
		sprintf(buf, "Ship Destroyed: %s (%s) on Team %d", code.c_str(), name.c_str(), (tid - kTeam1) + 1);
	else
		sprintf(buf, "Ship Destroyed: %s (%s) on Team %d", code.c_str(), name.c_str(), (tid - kTeam1) + 1);
	for (int team = (int)kTeam1; team <= (int)kTeam6; team++)
		gScriptInterface.mMission()->mDisplayMessage(static_cast<eTeamID>(team), buf);
		

	SomeShip ms;

	ms.tid = tid;
	ms.code = code;
	ms.name = name;
	ms.health = 0.0f;
	
	shipsDestroyed.push_back(ms);
	
}


void tWorldConditions::mSetShipDisengaged(eTeamID tid, std::string code, std::string name)

{ 
	char buf[255];

	tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle(tid);
	 
	if (tci->mGetTag() == kTagA )
	   sprintf(buf, "Ship Disengaged: %s (%s) on Team %d", code.c_str(), name.c_str(), (tid - kTeam1) + 1);
	else
	   sprintf(buf, "Ship Disengaged: %s (%s) on Team %d", code.c_str(), name.c_str(), (tid - kTeam1) + 1);
	 
	  for (int team = (int)kTeam1; team <= (int)kTeam6; team++)
	  gScriptInterface.mMission()->mDisplayMessage(static_cast<eTeamID>(team), buf);

	SomeShip ms;

	ms.tid = tid;
	ms.code = code;
	ms.name = name;
	ms.health = 0.0f;
	
	shipsDisengaged.push_back(ms);
	
}

void tWorldConditions::mSetShipCaptured(eTeamID tid, std::string code, std::string name)
{ 
	
	char buf[255];
	tTeamInfo * tci = gScriptInterface.mMission()->mGetTeamHandle(tid);
	if (tci->mGetTag() == kTagA)
		sprintf(buf, "Ship %s (%s) Captured by Team %d", code.c_str(), name.c_str(), (tid - kTeam1) + 1);
	else
		sprintf(buf, "Ship %s (%s) Captured by Team %d", code.c_str(), name.c_str(), (tid - kTeam1) + 1);
	for (int team = (int)kTeam1; team <= (int)kTeam6; team++)
		gScriptInterface.mMission()->mDisplayMessage(static_cast<eTeamID>(team), buf);

}

